<?php

declare(strict_types=1);

/*
 * eduVPN - End-user friendly VPN.
 *
 * Copyright: 2014-2023, The Commons Conservancy eduVPN Programme
 * SPDX-License-Identifier: AGPL-3.0+
 */

namespace Vpn\Portal;

class Dns
{
    /**
     * Obtain an IpNetList containing all IPv4 addresses a hostname resolves
     * to or an empty list if it does not resolve. It removes duplicates
     * (if any), we saw for example `gethostbynamel` on `localhost` returning
     * twice `127.0.0.1` for some reason...
     */
    public static function ipFour(string $dnsName): IpNetList
    {
        if (false === $ipFourList = gethostbynamel($dnsName)) {
            // unable to resolve to IPv4 address
            return new IpNetList();
        }

        $ipNetList = new IpNetList();
        foreach ($ipFourList as $ipFour) {
            $ipNetList->add(Ip::fromIp($ipFour));
        }

        return $ipNetList;
    }
}
